Use Case:  Remove content from public site
==========================================

Actor
-----

Reviewer

Assumptions
-----------

* Reviewer has logged into the CMF (see :doc:`LoginAsMember`).

* Content has been published which now needs to be unpublished
  (see :doc:`ApproveForPublication`).

Procedure
---------

1. Navigate to the content item you wish to remove from the
   publically visible site.

2. Select 'Reject' from the actions box.

3. Enter comments explaining why the object is being removed from the public
   site.

4. Select the "Reject" button. The system moves the item to the "private"
   state, making it no longer visible on your public site.
